==> bastille_1.3.0.orig.tar.gz: bastille-1.3.0.orig/Install.sh <==
#!/bin/sh

umask 077
RPM_BUILD_ROOT=""

mkdir -p $RPM_BUILD_ROOT/usr/sbin
mkdir -p $RPM_BUILD_ROOT/usr/lib/perl5/site_perl/Curses
mkdir -p $RPM_BUILD_ROOT/usr/lib/Bastille
mkdir -p $RPM_BUILD_ROOT/usr/share/Bastille
mkdir -p $RPM_BUILD_ROOT/usr/share/Bastille/Psad.pm
mkdir -p $RPM_BUILD_ROOT/var/log/psad
mkdir -p $RPM_BUILD_ROOT/etc/psad
 
cp AutomatedBastille $RPM_BUILD_ROOT/usr/sbin/
cp BastilleBackEnd $RPM_BUILD_ROOT/usr/sbin
cp Bastille_Curses.pm $RPM_BUILD_ROOT/usr/lib/perl5/site_perl
cp Bastille_Tk.pm $RPM_BUILD_ROOT/usr/lib/perl5/site_perl
cp Curses/Widgets.pm $RPM_BUILD_ROOT/usr/lib/perl5/site_perl/Curses
cp Default_Workstation $RPM_BUILD_ROOT/usr/share/Bastille
cp Default_Workstation_plus_Firewall $RPM_BUILD_ROOT/usr/share/Bastille
cp InteractiveBastille $RPM_BUILD_ROOT/usr/sbin
cp Questions.txt $RPM_BUILD_ROOT/usr/share/Bastille
cp Credits $RPM_BUILD_ROOT/usr/share/Bastille
cp UndoBastille $RPM_BUILD_ROOT/usr/sbin
chmod +x $RPM_BUILD_ROOT/usr/sbin/UndoBastille
cp bastille-firewall $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-firewall-reset $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-firewall-schedule $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-tmpdir-defense.sh $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-tmpdir.csh $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-tmpdir.sh $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-firewall.cfg $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-ipchains $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-netfilter $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-firewall-early.sh $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-firewall-pre-audit.sh $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/psad $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/psadwatchd $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/kmsgsd $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/diskmond $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/psad-init $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/Psad.pm/???* $RPM_BUILD_ROOT/usr/share/Bastille/Psad.pm
cp psad/psad.8 $RPM_BUILD_ROOT/usr/man/man8
mknod -m 600 $RPM_BUILD_ROOT/var/log/psadfifo p
make -C psad/whois-4.5.6
cp psad/whois-4.5.6/whois $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/psad_signatures $RPM_BUILD_ROOT/etc/psad
cp psad/psad_auto_ips $RPM_BUILD_ROOT/etc/psad
cp psad/psad.conf $RPM_BUILD_ROOT/etc/psad
PWDTMP=`pwd`
cd $RPM_BUILD_ROOT/usr/share/Bastille/Psad.pm
perl Makefile.PL
make
make test
make install
cd $PWDTMP
cp ifup-local $RPM_BUILD_ROOT/usr/share/Bastille
cp hosts.allow $RPM_BUILD_ROOT/usr/share/Bastille
cp Bastille/AccountSecurity.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Apache.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/API.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/BootSecurity.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/ConfigureMiscPAM.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/DisableUserTools.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/DNS.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/FilePermissions.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/FTP.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Firewall.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/HP_API.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/HP_UX.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Patches.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Logging.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/MiscellaneousDaemons.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/PatchDownload.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Printing.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/PSAD.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/RemoteAccess.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/SecureInetd.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Sendmail.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/TMPDIR.pm $RPM_BUILD_ROOT/usr/lib/Bastille

==> bastille_2.1.1.orig.tar.gz: bastille-2.1.1/Install.sh <==
#!/bin/sh

umask 077
RPM_BUILD_ROOT=""

mkdir -p $RPM_BUILD_ROOT/usr/sbin
mkdir -p $RPM_BUILD_ROOT/usr/lib/perl5/site_perl/Curses
mkdir -p $RPM_BUILD_ROOT/usr/lib/Bastille
mkdir -p $RPM_BUILD_ROOT/usr/share/Bastille
mkdir -p $RPM_BUILD_ROOT/var/log/psad
mkdir -p $RPM_BUILD_ROOT/var/lib/psad
mkdir -p $RPM_BUILD_ROOT/var/run/psad
mkdir -p $RPM_BUILD_ROOT/etc/psad
mkdir -p $RPM_BUILD_ROOT/var/lock/subsys/bastille
 
cp AutomatedBastille $RPM_BUILD_ROOT/usr/sbin/
cp BastilleBackEnd $RPM_BUILD_ROOT/usr/sbin
cp Bastille_Curses.pm $RPM_BUILD_ROOT/usr/lib/perl5/site_perl
cp Bastille_Tk.pm $RPM_BUILD_ROOT/usr/lib/perl5/site_perl
cp Curses/Widgets.pm $RPM_BUILD_ROOT/usr/lib/perl5/site_perl/Curses
cp Default_Workstation $RPM_BUILD_ROOT/usr/share/Bastille
cp Default_Workstation_plus_Firewall $RPM_BUILD_ROOT/usr/share/Bastille
cp InteractiveBastille $RPM_BUILD_ROOT/usr/sbin
cp Questions.txt $RPM_BUILD_ROOT/usr/share/Bastille
cp Credits $RPM_BUILD_ROOT/usr/share/Bastille
cp RevertBastille $RPM_BUILD_ROOT/usr/sbin
ln -s $RPM_BUILD_ROOT/usr/sbin/RevertBastille $RPM_BUILD_ROOT/usr/sbin/UndoBastille
cp bastille $RPM_BUILD_ROOT/usr/sbin
chmod +x $RPM_BUILD_ROOT/usr/sbin/RevertBastille
cp bastille-firewall $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-firewall-reset $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-firewall-schedule $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-tmpdir-defense.sh $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-tmpdir.csh $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-tmpdir.sh $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-firewall.cfg $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-ipchains $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-netfilter $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-firewall-early.sh $RPM_BUILD_ROOT/usr/share/Bastille
cp bastille-firewall-pre-audit.sh $RPM_BUILD_ROOT/usr/share/Bastille
cp complete.xbm $RPM_BUILD_ROOT/usr/share/Bastille
cp incomplete.xbm $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/psad $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/psadwatchd $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/kmsgsd $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/diskmond $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/psad-init $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/psad.8 $RPM_BUILD_ROOT/usr/man/man8
mknod -m 600 $RPM_BUILD_ROOT/var/log/psadfifo p
make -C psad/whois-4.5.29
cp psad/whois-4.5.29/whois $RPM_BUILD_ROOT/usr/share/Bastille
cp psad/psad_signatures $RPM_BUILD_ROOT/etc/psad
cp psad/psad_auto_ips $RPM_BUILD_ROOT/etc/psad
cp psad/psad.conf $RPM_BUILD_ROOT/etc/psad
cp -r psad/Psad.pm $RPM_BUILD_ROOT/usr/share/Bastille
PWDTMP=`pwd`
cd $RPM_BUILD_ROOT/usr/share/Bastille/Psad.pm
perl Makefile.PL
make
make test
make install
cd $PWDTMP
cp -r psad/Unix-Syslog-0.98 $RPM_BUILD_ROOT/usr/share/Bastille
PWDTMP=`pwd`
cd $RPM_BUILD_ROOT/usr/share/Bastille/Unix-Syslog-0.98
perl Makefile.PL
make
make test
make install
cd $PWDTMP
cp ifup-local $RPM_BUILD_ROOT/usr/share/Bastille
cp hosts.allow $RPM_BUILD_ROOT/usr/share/Bastille
cp Bastille/AccountSecurity.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Apache.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/API.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/BootSecurity.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/ConfigureMiscPAM.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/DisableUserTools.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/DNS.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/FilePermissions.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/FTP.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Firewall.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/HP_API.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/HP_UX.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/IOLoader.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Patches.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Logging.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/MiscellaneousDaemons.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/PatchDownload.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Printing.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/PSAD.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/RemoteAccess.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/SecureInetd.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/Sendmail.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/TMPDIR.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/test_AccountSecurity.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/test_Apache.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/test_DNS.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/test_FTP.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/test_HP_UX.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/test_MiscellaneousDaemons.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/test_SecureInetd.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/test_Sendmail.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/TestAPI.pm $RPM_BUILD_ROOT/usr/lib/Bastille
cp Bastille/IPFilter.pm $RPM_BUILD_ROOT/usr/lib/Bastille
